@@ -476,7 +476,7 @@ class Wrapper:
 
         dest_obj = dict(
             label_id=label_info["label_id"],
-            annotation_id=detail["annotation_id"] if detail["annotation_id"] is not None else str(uuid.uuid4()),
+            annotation_id=detail["annotation_id"] if detail.get("annotation_id") is not None else str(uuid.uuid4()),
             account_id=self.api.account_id,
             data_holding_type=data_holding_type,
             data=detail["data"],
@@ -505,7 +505,7 @@ class Wrapper:
         input_data_id: str,
         simple_annotation_json: str,
         annotation_specs_labels: List[LabelV1],
-    ) -> None:
+    ) -> bool:
         """
         AnnoFabからダウンロードしたアノテーションzip配下のJSONと同じフォーマット（Simple Annotation)の内容から、アノテーションを登録する。
 
@@ -515,6 +515,8 @@ class Wrapper:
             input_data_id:
             simple_annotation_json:
 
+        Returns:
+            True:アノテーション情報をした。False: 登録するアノテーション情報がなかったため、登録しなかった。
         """
         parser = SimpleAnnotationDirParser(Path(simple_annotation_json))
         annotation = parser.load_json()
@@ -522,7 +524,7 @@ class Wrapper:
         details = annotation["details"]
         if len(details) == 0:
             logger.warning(f"simple_annotation_json='{simple_annotation_json}'にアノテーション情報は記載されていなかったので、スキップします。")
-            return None
+            return False
 
         request_details: List[Dict[str, Any]] = []
         for detail in details:
@@ -533,7 +535,7 @@ class Wrapper:
                 request_details.append(request_detail)
         if len(request_details) == 0:
             logger.warning(f"simple_annotation_json='{simple_annotation_json}'に、登録できるアノテーションはなかったので、スキップします。")
-            return None
+            return False
 
         old_annotation, _ = self.api.get_editor_annotation(project_id, task_id, input_data_id)
         updated_datetime = old_annotation["updated_datetime"] if old_annotation is not None else None
@@ -546,7 +548,7 @@ class Wrapper:
             "updated_datetime": updated_datetime,
         }
         self.api.put_annotation(project_id, task_id, input_data_id, request_body=request_body)
-        return None
+        return True
 
     #########################################
     # Public Method : AnnotationSpecs
@@ -755,7 +757,7 @@ class Wrapper:
 
         Args:
             project_id: プロジェクトID
-            data: アップロード対象のdata. ``requests.put`` メソッドの ``data``引数にそのまま渡す。
+            data: アップロード対象のdata. ``requests.put`` メソッドの ``data`` 引数にそのまま渡す。
             content_type: アップロードするfile objectのMIME Type.
 
         Returns:
@@ -1485,7 +1487,7 @@ class Wrapper:
         Args:
             project_id: プロジェクトID
             image_id: 作業ガイド画像ID
-            data: アップロード対象のdata. ``requests.put`` メソッドの ``data``引数にそのまま渡す。
+            data: アップロード対象のdata. ``requests.put`` メソッドの ``data`` 引数にそのまま渡す。
             content_type: アップロードするファイルのMIME Type.
 
         Returns:
